@@ -1,8 +1,10 @@
 package Specio::Constraint::AnyIsa;
-$Specio::Constraint::AnyIsa::VERSION = '0.11';
+
 use strict;
 use warnings;
 
+our $VERSION = '0.12';
+
 use B ();
 use Role::Tiny::With;
 use Scalar::Util ();
@@ -14,7 +16,7 @@ with 'Specio::Constraint::Role::IsaType';
 
 {
     my $Defined = t('Defined');
-    sub _build_parent { $Defined }
+    sub _build_parent {$Defined}
 }
 
 {
@@ -32,7 +34,7 @@ with 'Specio::Constraint::Role::IsaType';
             . B::perlstring( $self->class ) . ')';
     };
 
-    sub _build_inline_generator { $_inline_generator }
+    sub _build_inline_generator {$_inline_generator}
 }
 
 __PACKAGE__->_ooify();
@@ -45,15 +47,13 @@ __END__
 
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 Specio::Constraint::AnyIsa - A class for constraints which require a class name or an object that inherit from a specific class
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 SYNOPSIS
 
@@ -90,8 +90,7 @@ Returns the class name passed to the constructor.
 =head1 ROLES
 
 This class does the L<Specio::Constraint::Role::IsaType>,
-L<Specio::Constraint::Role::Interface>, L<Specio::Role::Inlinable>, and
-L<MooseX::Clone> roles.
+L<Specio::Constraint::Role::Interface>, and L<Specio::Role::Inlinable> roles.
 
 =head1 AUTHOR
 
@@ -99,7 +98,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Dave Rolsky.
+This software is Copyright (c) 2015 by Dave Rolsky.
 
 This is free software, licensed under:
 
